@@ -47,6 +47,7 @@ class KFileItemList;
 class KJob;
 class KNewFileMenu;
 class KHelpMenu;
+class KToolBarPopupAction;
 class QToolButton;
 class QIcon;
 class PlacesPanel;
@@ -255,6 +256,9 @@ private slots:
     /** Replaces the URL navigator by a search box to find files. */
     void find();
 
+    /** Updates the state of the search action according to the view container. */
+    void updateSearchAction();
+
     /**
      * Updates the text of the paste action dependent on
      * the number of items which are in the clipboard.
@@ -381,6 +385,11 @@ private slots:
      */
     void openNewActivatedTab();
 
+    /**
+     * Adds the current URL as an entry to the Places panel
+     */
+    void addToPlaces();
+
     /**
      * Opens a new tab in the background showing the URL \a url.
      */
@@ -501,6 +510,36 @@ private slots:
      */
     void slotToolBarActionMiddleClicked(QAction *action);
 
+    /**
+     * Is called before the Back popup menu is shown. This slot will populate
+     * the menu with history data
+     */
+    void slotAboutToShowBackPopupMenu();
+
+    /**
+      * This slot is used by the Back Popup Menu to go back to a specific
+      * history index. The QAction::data will carry an int with the index
+      * to go to.
+      */
+    void slotGoBack(QAction* action);
+
+    /**
+     * Middle clicking Back/Forward will open the resulting folder in a new tab.
+     */
+    void slotBackForwardActionMiddleClicked(QAction *action);
+
+    /**
+     * Is called before the Forward popup menu is shown. This slot will populate
+     * the menu with history data
+     */
+    void slotAboutToShowForwardPopupMenu();
+
+    /**
+      * This slot is used by the Forward Popup Menu to go forward to a specific
+      * history index. The QAction::data will carry an int with the index
+      * to go to.
+      */
+    void slotGoForward(QAction* action);
 private:
     /**
      * Sets up the various menus and actions and connects them.
@@ -512,7 +551,7 @@ private:
      */
     void setupDockWidgets();
 
-    void updateEditActions();
+    void updateFileAndEditActions();
     void updateViewActions();
     void updateGoActions();
 
@@ -591,6 +630,9 @@ private:
     TerminalPanel* m_terminalPanel;
     PlacesPanel* m_placesPanel;
     bool m_tearDownFromPlacesRequested;
+
+    KToolBarPopupAction* m_backAction;
+    KToolBarPopupAction* m_forwardAction;
 };
 
 inline DolphinViewContainer* DolphinMainWindow::activeViewContainer() const
