@@ -19,9 +19,10 @@
 
 #include "dolphinrecenttabsmenu.h"
 
-#include <KLocalizedString>
 #include <KAcceleratorManager>
+#include <KLocalizedString>
 #include <kio/global.h>
+
 #include <QMenu>
 
 DolphinRecentTabsMenu::DolphinRecentTabsMenu(QObject* parent) :
@@ -86,7 +87,7 @@ void DolphinRecentTabsMenu::handleAction(QAction* action)
         const QByteArray state = action->data().toByteArray();
         removeAction(action);
         delete action;
-        action = 0;
+        action = nullptr;
         emit restoreClosedTab(state);
         emit closedTabsCountChanged(menu()->actions().size() - 2);
     }
