@@ -61,6 +61,8 @@ KItemListController::KItemListController(KItemModelBase* model, KItemListView* v
             this, &KItemListController::slotChangeCurrentItem);
     connect(m_selectionManager, &KItemListSelectionManager::currentChanged,
             m_keyboardManager, &KItemListKeyboardSearchManager::slotCurrentChanged);
+    connect(m_selectionManager, &KItemListSelectionManager::selectionChanged,
+            m_keyboardManager, &KItemListKeyboardSearchManager::slotSelectionChanged);
 
     m_autoActivationTimer = new QTimer(this);
     m_autoActivationTimer->setSingleShot(true);
@@ -472,19 +474,18 @@ void KItemListController::slotChangeCurrentItem(const QString& text, bool search
     if (!m_model || m_model->count() == 0) {
         return;
     }
-    const int currentIndex = m_selectionManager->currentItem();
     int index;
     if (searchFromNextItem) {
+        const int currentIndex = m_selectionManager->currentItem();
         index = m_model->indexForKeyboardSearch(text, (currentIndex + 1) % m_model->count());
     } else {
-        index = m_model->indexForKeyboardSearch(text, currentIndex);
+        index = m_model->indexForKeyboardSearch(text, 0);
     }
     if (index >= 0) {
         m_selectionManager->setCurrentItem(index);
 
         if (m_selectionBehavior != NoSelection) {
-            m_selectionManager->clearSelection();
-            m_selectionManager->setSelected(index, 1);
+            m_selectionManager->replaceSelection(index);
             m_selectionManager->beginAnchoredSelection(index);
         }
 
@@ -524,7 +525,7 @@ void KItemListController::slotAutoActivationTimeout()
 
 bool KItemListController::inputMethodEvent(QInputMethodEvent* event)
 {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
     return false;
 }
 
@@ -844,8 +845,8 @@ bool KItemListController::mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event,
 
 bool KItemListController::dragEnterEvent(QGraphicsSceneDragDropEvent* event, const QTransform& transform)
 {
-    Q_UNUSED(event);
-    Q_UNUSED(transform);
+    Q_UNUSED(event)
+    Q_UNUSED(transform)
 
     DragAndDropHelper::clearUrlListMatchesUrlCache();
 
@@ -854,8 +855,8 @@ bool KItemListController::dragEnterEvent(QGraphicsSceneDragDropEvent* event, con
 
 bool KItemListController::dragLeaveEvent(QGraphicsSceneDragDropEvent* event, const QTransform& transform)
 {
-    Q_UNUSED(event);
-    Q_UNUSED(transform);
+    Q_UNUSED(event)
+    Q_UNUSED(transform)
 
     m_autoActivationTimer->stop();
     m_view->setAutoScroll(false);
@@ -968,14 +969,14 @@ bool KItemListController::dropEvent(QGraphicsSceneDragDropEvent* event, const QT
 
 bool KItemListController::hoverEnterEvent(QGraphicsSceneHoverEvent* event, const QTransform& transform)
 {
-    Q_UNUSED(event);
-    Q_UNUSED(transform);
+    Q_UNUSED(event)
+    Q_UNUSED(transform)
     return false;
 }
 
 bool KItemListController::hoverMoveEvent(QGraphicsSceneHoverEvent* event, const QTransform& transform)
 {
-    Q_UNUSED(transform);
+    Q_UNUSED(transform)
     if (!m_model || !m_view) {
         return false;
     }
@@ -1006,8 +1007,8 @@ bool KItemListController::hoverMoveEvent(QGraphicsSceneHoverEvent* event, const
 
 bool KItemListController::hoverLeaveEvent(QGraphicsSceneHoverEvent* event, const QTransform& transform)
 {
-    Q_UNUSED(event);
-    Q_UNUSED(transform);
+    Q_UNUSED(event)
+    Q_UNUSED(transform)
 
     if (!m_model || !m_view) {
         return false;
@@ -1024,15 +1025,15 @@ bool KItemListController::hoverLeaveEvent(QGraphicsSceneHoverEvent* event, const
 
 bool KItemListController::wheelEvent(QGraphicsSceneWheelEvent* event, const QTransform& transform)
 {
-    Q_UNUSED(event);
-    Q_UNUSED(transform);
+    Q_UNUSED(event)
+    Q_UNUSED(transform)
     return false;
 }
 
 bool KItemListController::resizeEvent(QGraphicsSceneResizeEvent* event, const QTransform& transform)
 {
-    Q_UNUSED(event);
-    Q_UNUSED(transform);
+    Q_UNUSED(event)
+    Q_UNUSED(transform)
     return false;
 }
 
