@@ -22,9 +22,9 @@
 
 #include "kitemlistkeyboardsearchmanager.h"
 
-
 KItemListKeyboardSearchManager::KItemListKeyboardSearchManager(QObject* parent) :
     QObject(parent),
+    m_isSearchRestarted(false),
     m_timeout(1000)
 {
     m_keyboardInputTime.invalidate();
@@ -34,11 +34,16 @@ KItemListKeyboardSearchManager::~KItemListKeyboardSearchManager()
 {
 }
 
-void KItemListKeyboardSearchManager::addKeys(const QString& keys)
+bool KItemListKeyboardSearchManager::shouldClearSearchIfInputTimeReached()
 {
     const bool keyboardTimeWasValid = m_keyboardInputTime.isValid();
     const qint64 keyboardInputTimeElapsed = m_keyboardInputTime.restart();
-    if (keyboardInputTimeElapsed > m_timeout || !keyboardTimeWasValid) {
+    return (keyboardInputTimeElapsed > m_timeout) || !keyboardTimeWasValid;
+}
+
+void KItemListKeyboardSearchManager::addKeys(const QString& keys)
+{
+    if (shouldClearSearchIfInputTimeReached()) {
         m_searchedString.clear();
     }
 
@@ -46,7 +51,7 @@ void KItemListKeyboardSearchManager::addKeys(const QString& keys)
 
     // Do not start a new search if the user pressed Space. Only add
     // it to the search string if a search is in progress already.
-    if (newSearch && keys == QLatin1String(" ")) {
+    if (newSearch && keys == QLatin1Char(' ')) {
         return;
     }
 
@@ -59,9 +64,13 @@ void KItemListKeyboardSearchManager::addKeys(const QString& keys)
         const bool sameKey = m_searchedString.length() > 1 && m_searchedString.count(firstKey) == m_searchedString.length();
 
         // Searching for a matching item should start from the next item if either
-        // 1. a new search is started, or
+        // 1. a new search is started and a search has not been restarted or
         // 2. a 'repeated key' search is done.
-        const bool searchFromNextItem = newSearch || sameKey;
+        const bool searchFromNextItem = (!m_isSearchRestarted && newSearch) || sameKey;
+
+        // to remember not to searchFromNextItem if selection was deselected
+        // loosing keyboard search context basically
+        m_isSearchRestarted = false;
 
         emit changeCurrentItem(sameKey ? firstKey : m_searchedString, searchFromNextItem);
     }
@@ -80,15 +89,24 @@ qint64 KItemListKeyboardSearchManager::timeout() const
 
 void KItemListKeyboardSearchManager::cancelSearch()
 {
+    m_isSearchRestarted = true;
     m_searchedString.clear();
 }
 
 void KItemListKeyboardSearchManager::slotCurrentChanged(int current, int previous)
 {
-    Q_UNUSED(previous);
+    Q_UNUSED(previous)
 
     if (current < 0) {
         // The current item has been removed. We should cancel the search.
         cancelSearch();
     }
 }
+
+void KItemListKeyboardSearchManager::slotSelectionChanged(const KItemSet& current, const KItemSet& previous)
+{
+    if (!previous.isEmpty() && current.isEmpty() && previous.count() > 0 && current.count() == 0) {
+        // The selection has been emptied. We should cancel the search.
+        cancelSearch();
+    }
+}
