@@ -24,6 +24,7 @@
 #define KITEMLISTKEYBOARDSEARCHMANAGER_H
 
 #include "dolphin_export.h"
+#include "kitemviews/kitemset.h"
 
 #include <QElapsedTimer>
 #include <QObject>
@@ -59,10 +60,12 @@ public:
     qint64 timeout() const;
 
     void cancelSearch();
+    bool shouldClearSearchIfInputTimeReached();
 
 public slots:
 
     void slotCurrentChanged(int current, int previous);
+    void slotSelectionChanged(const KItemSet& current, const KItemSet& previous);
 
 signals:
     /**
@@ -78,6 +81,7 @@ signals:
 
 private:
     QString m_searchedString;
+    bool m_isSearchRestarted;
     QElapsedTimer m_keyboardInputTime;
     qint64 m_timeout;
 };
