@@ -36,7 +36,6 @@
 #include <QMenu>
 
 #include "dolphin_informationpanelsettings.h"
-#include "filemetadataconfigurationdialog.h"
 
 InformationPanel::InformationPanel(QWidget* parent) :
     Panel(parent),
@@ -168,7 +167,8 @@ void InformationPanel::contextMenuEvent(QContextMenuEvent* event)
     Panel::contextMenuEvent(event);
 }
 
-void InformationPanel::showContextMenu(const QPoint &pos) {
+void InformationPanel::showContextMenu(const QPoint &pos)
+{
     QMenu popup(this);
 
     QAction* previewAction = popup.addAction(i18nc("@action:inmenu", "Preview"));
@@ -176,8 +176,16 @@ void InformationPanel::showContextMenu(const QPoint &pos) {
     previewAction->setCheckable(true);
     previewAction->setChecked(InformationPanelSettings::previewsShown());
 
+    QAction* previewAutoPlayAction = popup.addAction(i18nc("@action:inmenu", "Auto-Play media files"));
+    previewAutoPlayAction->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
+    previewAutoPlayAction->setCheckable(true);
+    previewAutoPlayAction->setChecked(InformationPanelSettings::previewsAutoPlay());
+
     QAction* configureAction = popup.addAction(i18nc("@action:inmenu", "Configure..."));
     configureAction->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
+    if (m_inConfigurationMode) {
+        configureAction->setEnabled(false);
+    }
 
     QAction* dateformatAction = popup.addAction(i18nc("@action:inmenu", "Condensed Date"));
     dateformatAction->setIcon(QIcon::fromTheme(QStringLiteral("change-date-symbolic")));
@@ -185,7 +193,8 @@ void InformationPanel::showContextMenu(const QPoint &pos) {
     dateformatAction->setChecked(InformationPanelSettings::dateFormat() == static_cast<int>(Baloo::DateFormats::ShortFormat));
 
     popup.addSeparator();
-    foreach (QAction* action, customContextMenuActions()) {
+    const auto actions = customContextMenuActions();
+    for (QAction *action : actions) {
         popup.addAction(action);
     }
 
@@ -201,19 +210,17 @@ void InformationPanel::showContextMenu(const QPoint &pos) {
         InformationPanelSettings::setPreviewsShown(isChecked);
         m_content->refreshPreview();
     } else if (action == configureAction) {
-        FileMetaDataConfigurationDialog* dialog = new FileMetaDataConfigurationDialog(this);
-        dialog->setDescription(i18nc("@label::textbox",
-                                     "Select which data should be shown in the information panel:"));
-        dialog->setItems(m_content->items());
-        dialog->setAttribute(Qt::WA_DeleteOnClose);
-        dialog->show();
-        connect(dialog, &FileMetaDataConfigurationDialog::destroyed, m_content, &InformationPanelContent::refreshMetaData);
+        m_inConfigurationMode = true;
+        m_content->configureShownProperties();
     }
     if (action == dateformatAction) {
         int dateFormat = static_cast<int>(isChecked ? Baloo::DateFormats::ShortFormat : Baloo::DateFormats::LongFormat);
 
         InformationPanelSettings::setDateFormat(dateFormat);
         m_content->refreshMetaData();
+    } else if (action == previewAutoPlayAction) {
+        InformationPanelSettings::setPreviewsAutoPlay(isChecked);
+        m_content->setPreviewAutoPlay(isChecked);
     }
 }
 
@@ -311,7 +318,7 @@ void InformationPanel::slotFilesAdded(const QString& directory)
 
 void InformationPanel::slotFilesChanged(const QStringList& files)
 {
-    foreach (const QString& fileName, files) {
+    for (const QString& fileName : files) {
         if (m_shownUrl == QUrl::fromLocalFile(fileName)) {
             showItemInfo();
             break;
@@ -321,7 +328,7 @@ void InformationPanel::slotFilesChanged(const QStringList& files)
 
 void InformationPanel::slotFilesRemoved(const QStringList& files)
 {
-    foreach (const QString& fileName, files) {
+    for (const QString& fileName : files) {
         if (m_shownUrl == QUrl::fromLocalFile(fileName)) {
             // the currently shown item has been removed, show
             // the parent directory as fallback
@@ -410,6 +417,7 @@ void InformationPanel::init()
 
     m_content = new InformationPanelContent(this);
     connect(m_content, &InformationPanelContent::urlActivated, this, &InformationPanel::urlActivated);
+    connect(m_content, &InformationPanelContent::configurationFinished, this, [this]() { m_inConfigurationMode = false; });
 
     QVBoxLayout* layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
