@@ -46,11 +46,18 @@
 #include <QTimer>
 #include <QVBoxLayout>
 #include <QStyle>
+#include <QPainter>
+#include <QBitmap>
+#include <QLinearGradient>
+#include <QPolygon>
 
 #include "dolphin_informationpanelsettings.h"
 #include "phononwidget.h"
 #include "pixmapviewer.h"
 
+const int PLAY_ARROW_SIZE = 24;
+const int PLAY_ARROW_BORDER_SIZE = 2;
+
 InformationPanelContent::InformationPanelContent(QWidget* parent) :
     QWidget(parent),
     m_item(),
@@ -61,7 +68,8 @@ InformationPanelContent::InformationPanelContent(QWidget* parent) :
     m_nameLabel(nullptr),
     m_metaDataWidget(nullptr),
     m_metaDataArea(nullptr),
-    m_placesItemModel(nullptr)
+    m_placesItemModel(nullptr),
+    m_isVideo(false)
 {
     parent->installEventFilter(this);
 
@@ -161,11 +169,47 @@ void InformationPanelContent::showItem(const KFileItem& item)
     if (item != m_item) {
         m_item = item;
 
+        m_preview->stopAnimatedImage();
         refreshMetaData();
     }
     refreshPreview();
 }
 
+void InformationPanelContent::refreshPixmapView()
+{
+    // If there is a preview job, kill it to prevent that we have jobs for
+    // multiple items running, and thus a race condition (bug 250787).
+    if (m_previewJob) {
+        m_previewJob->kill();
+    }
+
+    // try to get a preview pixmap from the item...
+
+    // Mark the currently shown preview as outdated. This is done
+    // with a small delay to prevent a flickering when the next preview
+    // can be shown within a short timeframe. This timer is not started
+    // for directories, as directory previews might fail and return the
+    // same icon.
+    if (!m_item.isDir()) {
+        m_outdatedPreviewTimer->start();
+    }
+
+    QStringList plugins = KIO::PreviewJob::availablePlugins();
+    m_previewJob = new KIO::PreviewJob(KFileItemList() << m_item,
+                                       QSize(m_preview->width(), m_preview->height()),
+                                       &plugins);
+    m_previewJob->setScaleType(KIO::PreviewJob::Unscaled);
+    m_previewJob->setIgnoreMaximumSize(m_item.isLocalFile());
+    if (m_previewJob->uiDelegate()) {
+        KJobWidgets::setWindow(m_previewJob, this);
+    }
+
+    connect(m_previewJob.data(), &KIO::PreviewJob::gotPreview,
+            this, &InformationPanelContent::showPreview);
+    connect(m_previewJob.data(), &KIO::PreviewJob::failed,
+            this, &InformationPanelContent::showIcon);
+}
+
 void InformationPanelContent::refreshPreview()
 {
     // If there is a preview job, kill it to prevent that we have jobs for
@@ -174,70 +218,70 @@ void InformationPanelContent::refreshPreview()
         m_previewJob->kill();
     }
 
+    m_preview->setCursor(Qt::ArrowCursor);
+    bool usePhonon = false;
     setNameLabelText(m_item.text());
     if (InformationPanelSettings::previewsShown()) {
 
         const QUrl itemUrl = m_item.url();
-        const bool isSearchUrl = itemUrl.scheme().contains(QStringLiteral("search")) && m_item.localPath().isEmpty();
+        const bool isSearchUrl = itemUrl.scheme().contains(QLatin1String("search")) && m_item.localPath().isEmpty();
         if (isSearchUrl) {
             m_preview->show();
 
             // in the case of a search-URL the URL is not readable for humans
             // (at least not useful to show in the Information Panel)
             m_preview->setPixmap(
-                QIcon::fromTheme(QStringLiteral("nepomuk")).pixmap(KIconLoader::SizeEnormous, KIconLoader::SizeEnormous)
+                QIcon::fromTheme(QStringLiteral("baloo")).pixmap(KIconLoader::SizeEnormous, KIconLoader::SizeEnormous)
             );
         } else {
-            // try to get a preview pixmap from the item...
 
-            // Mark the currently shown preview as outdated. This is done
-            // with a small delay to prevent a flickering when the next preview
-            // can be shown within a short timeframe. This timer is not started
-            // for directories, as directory previews might fail and return the
-            // same icon.
-            if (!m_item.isDir()) {
-                m_outdatedPreviewTimer->start();
-            }
-
-            QStringList plugins = KIO::PreviewJob::availablePlugins();
-            m_previewJob = new KIO::PreviewJob(KFileItemList() << m_item,
-                                               QSize(m_preview->width(), m_preview->height()),
-                                               &plugins);
-            m_previewJob->setScaleType(KIO::PreviewJob::Unscaled);
-            m_previewJob->setIgnoreMaximumSize(m_item.isLocalFile());
-            if (m_previewJob->uiDelegate()) {
-                KJobWidgets::setWindow(m_previewJob, this);
-            }
-
-            connect(m_previewJob.data(), &KIO::PreviewJob::gotPreview,
-                    this, &InformationPanelContent::showPreview);
-            connect(m_previewJob.data(), &KIO::PreviewJob::failed,
-                    this, &InformationPanelContent::showIcon);
+            refreshPixmapView();
 
             const QString mimeType = m_item.mimetype();
-            const bool isVideo = mimeType.startsWith(QLatin1String("video/"));
-            const bool usePhonon = mimeType.startsWith(QLatin1String("audio/")) || isVideo;
+            const bool isAnimatedImage = m_preview->isAnimatedImage(itemUrl.toLocalFile());
+            m_isVideo = !isAnimatedImage && mimeType.startsWith(QLatin1String("video/"));
+            usePhonon = m_isVideo || mimeType.startsWith(QLatin1String("audio/"));
 
             if (usePhonon) {
+                // change the cursor of the preview
+                m_preview->setCursor(Qt::PointingHandCursor);
+                m_preview->installEventFilter(m_phononWidget);
 
-                if (InformationPanelSettings::previewsAutoPlay() && isVideo) {
-                    // hides the preview now to avoid flickering when the autoplay video starts
-                    m_preview->hide();
-                } else {
-                    // the video won't play before the preview is displayed
-                    m_preview->show();
+                // if the video is playing, has been paused or stopped
+                // we don't need to update the preview/phonon widget states
+                // unless the previewed file has changed,
+                // or the setting previewshown has changed
+                if ((m_phononWidget->state() != Phonon::State::PlayingState &&
+                     m_phononWidget->state() != Phonon::State::PausedState &&
+                     m_phononWidget->state() != Phonon::State::StoppedState) ||
+                        m_item.targetUrl() != m_phononWidget->url() ||
+                        (!m_preview->isVisible() &&! m_phononWidget->isVisible())) {
+
+                    if (InformationPanelSettings::previewsAutoPlay() && m_isVideo) {
+                        // hides the preview now to avoid flickering when the autoplay video starts
+                        m_preview->hide();
+                    } else {
+                        // the video won't play before the preview is displayed
+                        m_preview->show();
+                    }
+
+                    m_phononWidget->show();
+                    m_phononWidget->setUrl(m_item.targetUrl(), m_isVideo ? PhononWidget::MediaKind::Video : PhononWidget::MediaKind::Audio);
+                    adjustWidgetSizes(parentWidget()->width());
                 }
-
-                m_phononWidget->show();
-                m_phononWidget->setUrl(m_item.targetUrl(), isVideo ? PhononWidget::MediaKind::Video : PhononWidget::MediaKind::Audio);
-                m_phononWidget->setVideoSize(m_preview->size());
             } else {
+                if (isAnimatedImage) {
+                    m_preview->setAnimatedImageFileName(itemUrl.toLocalFile());
+                }
                 // When we don't need it, hide the phonon widget first to avoid flickering
                 m_phononWidget->hide();
                 m_preview->show();
+                m_preview->removeEventFilter(m_phononWidget);
+                m_phononWidget->clearUrl();
             }
         }
     } else {
+        m_preview->stopAnimatedImage();
         m_preview->hide();
         m_phononWidget->hide();
     }
@@ -265,6 +309,8 @@ void InformationPanelContent::showItems(const KFileItemList& items)
         m_previewJob->kill();
     }
 
+    m_preview->stopAnimatedImage();
+
     m_preview->setPixmap(
         QIcon::fromTheme(QStringLiteral("dialog-information")).pixmap(KIconLoader::SizeEnormous, KIconLoader::SizeEnormous)
     );
@@ -319,10 +365,45 @@ void InformationPanelContent::showPreview(const KFileItem& item,
                                           const QPixmap& pixmap)
 {
     m_outdatedPreviewTimer->stop();
-    Q_UNUSED(item);
 
     QPixmap p = pixmap;
     KIconLoader::global()->drawOverlays(item.overlays(), p, KIconLoader::Desktop);
+
+    if (m_isVideo) {
+        // adds a play arrow
+
+        // compute relative pixel positions
+        const int zeroX = static_cast<int>(p.width() / 2 - PLAY_ARROW_SIZE / 2 / devicePixelRatio());
+        const int zeroY = static_cast<int>(p.height() / 2 - PLAY_ARROW_SIZE / 2 / devicePixelRatio());
+
+        QPolygon arrow;
+        arrow << QPoint(zeroX, zeroY);
+        arrow << QPoint(zeroX, zeroY + PLAY_ARROW_SIZE);
+        arrow << QPoint(zeroX + PLAY_ARROW_SIZE, zeroY + PLAY_ARROW_SIZE / 2);
+
+        QPainterPath path;
+        path.addPolygon(arrow);
+
+        QLinearGradient gradient(QPointF(zeroX, zeroY),
+                                 QPointF(zeroX + PLAY_ARROW_SIZE,zeroY + PLAY_ARROW_SIZE));
+
+        QColor whiteColor = Qt::white;
+        QColor blackColor = Qt::black;
+        gradient.setColorAt(0, whiteColor);
+        gradient.setColorAt(1, blackColor);
+
+        QBrush brush(gradient);
+
+        QPainter painter(&p);
+
+        QPen pen(blackColor, PLAY_ARROW_BORDER_SIZE, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
+        painter.setPen(pen);
+
+        painter.setRenderHint(QPainter::Antialiasing);
+        painter.drawPolygon(arrow);
+        painter.fillPath(path, brush);
+    }
+
     m_preview->setPixmap(p);
 }
 
@@ -343,6 +424,11 @@ KFileItemList InformationPanelContent::items()
 void InformationPanelContent::slotHasVideoChanged(bool hasVideo)
 {
     m_preview->setVisible(InformationPanelSettings::previewsShown() && !hasVideo);
+    if (m_preview->isVisible() && m_preview->size().width() != m_preview->pixmap().size().width()) {
+        // in case the information panel has been resized when the preview was not displayed
+        // we need to refresh its content
+        refreshPixmapView();
+    }
 }
 
 void InformationPanelContent::setPreviewAutoPlay(bool autoPlay) {
