@@ -53,11 +53,14 @@ class PhononWidget : public QWidget
 
         void setUrl(const QUrl &url, MediaKind kind);
         QUrl url() const;
+        void clearUrl();
 
         void setVideoSize(const QSize& size);
         QSize videoSize() const;
+        Phonon::State state() const;
 
         void setAutoPlay(bool autoPlay);
+        bool eventFilter(QObject *object, QEvent *event) override;
 
     signals:
         /**
@@ -86,11 +89,13 @@ class PhononWidget : public QWidget
         void applyVideoSize();
 
     private:
+        void togglePlayback();
+
         QUrl m_url;
         QSize m_videoSize;
 
         QToolButton *m_playButton;
-        QToolButton *m_stopButton;
+        QToolButton *m_pauseButton;
 
         QVBoxLayout *m_topLayout;
         Phonon::MediaObject *m_media;
