@@ -175,8 +175,8 @@ void PlacesItem::onDataValueChanged(const QByteArray& role,
                                     const QVariant& current,
                                     const QVariant& previous)
 {
-    Q_UNUSED(current);
-    Q_UNUSED(previous);
+    Q_UNUSED(current)
+    Q_UNUSED(previous)
 
     if (!m_bookmark.isNull()) {
         updateBookmarkForRole(role);
@@ -186,7 +186,7 @@ void PlacesItem::onDataValueChanged(const QByteArray& role,
 void PlacesItem::onDataChanged(const QHash<QByteArray, QVariant>& current,
                                const QHash<QByteArray, QVariant>& previous)
 {
-    Q_UNUSED(previous);
+    Q_UNUSED(previous)
 
     if (!m_bookmark.isNull()) {
         QHashIterator<QByteArray, QVariant> it(current);
