@@ -24,6 +24,7 @@
 #include <QWidget>
 
 class DolphinFacetsWidget;
+class DolphinQuery;
 class QLineEdit;
 class KSeparator;
 class QToolButton;
@@ -62,8 +63,8 @@ public:
     QString text() const;
 
     /**
-     * Sets the current path that is used as root for
-     * searching files, if "From Here" has been selected.
+     * Sets the current path that is used as root for searching files.
+     * If @url is the Home dir, "From Here" is selected instead.
      */
     void setSearchPath(const QUrl& url);
     QUrl searchPath() const;
@@ -137,7 +138,6 @@ private slots:
     void slotConfigurationChanged();
     void slotSearchTextChanged(const QString& text);
     void slotReturnPressed();
-    void slotFacetsButtonToggled();
     void slotFacetChanged();
     void slotSearchSaved();
 
@@ -153,12 +153,13 @@ private:
     QUrl balooUrlForSearching() const;
 
     /**
-     * Extracts information from the given Baloo search \a url to
-     * initialize the search box properly.
+     * Sets the searchbox UI with the parameters established by the \a query
      */
-    void fromBalooSearchUrl(const QUrl& url);
+    void updateFromQuery(const DolphinQuery& query);
 
-    void updateFacetsToggleButton();
+    void updateFacetsVisible();
+
+    bool isIndexingEnabled() const;
 
 private:
     bool m_startedSearching;
@@ -174,7 +175,6 @@ private:
     KSeparator* m_separator;
     QToolButton* m_fromHereButton;
     QToolButton* m_everywhereButton;
-    QToolButton* m_facetsToggleButton;
     DolphinFacetsWidget* m_facetsWidget;
 
     QUrl m_searchPath;
