@@ -37,6 +37,8 @@ class QAction;
 class QTimer;
 class UpdateItemStatesThread;
 
+class DolphinView;
+
 /**
  * @brief Observes all version control plugins.
  *
@@ -55,6 +57,8 @@ public:
 
     void setModel(KFileItemModel* model);
     KFileItemModel* model() const;
+    void setView(DolphinView* view);
+    DolphinView* view() const;
 
     QList<QAction*> actions(const KFileItemList& items) const;
 
@@ -126,7 +130,7 @@ private:
      * Returns a matching plugin for the given directory.
      * 0 is returned, if no matching plugin has been found.
      */
-    KVersionControlPlugin* searchPlugin(const QUrl& directory) const;
+    KVersionControlPlugin* searchPlugin(const QUrl& directory);
 
     /**
      * Returns true, if the directory contains a version control information.
@@ -139,11 +143,14 @@ private:
     bool m_silentUpdate; // if true, no messages will be send during the update
                          // of version states
 
+    DolphinView* m_view;
     KFileItemModel* m_model;
 
     QTimer* m_dirVerificationTimer;
 
+    bool m_pluginsInitialized;
     KVersionControlPlugin* m_plugin;
+    QList<KVersionControlPlugin*> m_plugins;
     UpdateItemStatesThread* m_updateItemStatesThread;
 
     friend class UpdateItemStatesThread;
